"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = universalDotenv;

var _fs = _interopRequireDefault(require("fs"));

var _path = _interopRequireDefault(require("path"));

var _dotenv = require("dotenv");

var _package = require("../package");

var _expand = _interopRequireDefault(require("./expand"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const dotenvPath = _path.default.resolve(process.cwd(), '.env');

const allowedEnvs = ['development', 'test', 'production'];

function universalDotenv({
  types: {
    valueToNode,
    logicalExpression,
    identifier
  }
}) {
  return {
    name: _package.name,

    pre() {
      this.NODE_ENV = allowedEnvs.includes(process.env.NODE_ENV) ? process.env.NODE_ENV : 'development';
      const before = { ...process.env
      };
      this.values = [`${dotenvPath}.${this.NODE_ENV}.local`, `${dotenvPath}.${this.NODE_ENV}`, this.NODE_ENV !== 'test' && `${dotenvPath}.local`, dotenvPath].filter(Boolean).filter(_fs.default.existsSync).reduce((values, file) => ({ ...(0, _expand.default)((0, _dotenv.parse)(_fs.default.readFileSync(file, {
          encoding: 'utf8'
        }))),
        ...values
      }), {});
      process.env = before;
    },

    visitor: {
      MemberExpression(node) {
        if (!node.get('object').matchesPattern('process.env')) {
          return;
        }

        const {
          value: key
        } = node.toComputedKey();

        if (key === 'NODE_ENV') {
          node.replaceWith(valueToNode(this.NODE_ENV));
        } else if (Object.prototype.hasOwnProperty.call(this.values, key)) {
          node.replaceWith(logicalExpression('||', identifier(`process.env.${key}`), valueToNode(this.values[key])));
        }
      }

    }
  };
}
//# sourceMappingURL=index.js.map